@@ -42,7 +42,7 @@ op = nk.optimizer.Sgd(ma, learning_rate=0.1)
 sr = nk.optimizer.SR(ma, diag_shift=0.1)
 
 # Create the optimization driver
-gs = nk.Vmc(hamiltonian=ha, sampler=sa, optimizer=op, n_samples=1000, sr=sr)
+gs = nk.VMC(hamiltonian=ha, sampler=sa, optimizer=op, n_samples=1000, sr=sr)
 
 # Create the TensorBoard logger
 logger = nk.logging.TensorBoardLog("tblogs/run1")
