@@ -14,7 +14,7 @@
 
 
 def info(obj, depth=None):
-    if hasattr(obj, "info"):
+    if hasattr(obj, "info") and callable(obj.info):
         return obj.info(depth)
     else:
         return str(obj)
