@@ -35,29 +35,37 @@ def _axis_reflection(axis: int, ndim: int) -> PGSymmetry:
     return PGSymmetry(M)
 
 
-def _grid_point_group(extent: Sequence[int], pbc: Sequence[bool]) -> PointGroup:
-    # axis permutations
-    # can exchange two axes iff they have the same kind of BC and length
-    # represent open BC by setting kind[i] = -extent[i], so just have to
-    # match these
-    axis_perm = []
-    axes = np.arange(len(extent), dtype=int)
-    extent = np.asarray(extent, dtype=int)
-    kind = np.where(pbc, extent, -extent)
+def _grid_point_group(
+    extent: Sequence[int], pbc: Sequence[bool], color_edges: bool
+) -> PointGroup:
+    """Point group of `Grid`, made up of axis permutations and flipping each axis."""
     ndim = len(extent)
-    for perm in permutations(axes):
-        if np.all(kind == kind[list(perm)]):
-            axis_perm.append(_perm_symm(perm))
-    result = PointGroup(axis_perm, ndim=ndim)
+    # Cannot exchange two axes if they are colored differently; otherwise,
+    # can only exchange them if they have the same kind of BC and length.
+    # Represent open BC by setting kind[i] = -extent[i], so just have to match these
+    if color_edges:
+        result = PointGroup([Identity()], ndim=ndim)
+    else:
+        axis_perm = []
+        axes = np.arange(ndim, dtype=int)
+        extent = np.asarray(extent, dtype=int)
+        kind = np.where(pbc, extent, -extent)
+        for perm in permutations(axes):
+            if np.all(kind == kind[list(perm)]):
+                if np.all(perm == axes):
+                    axis_perm.append(Identity())
+                else:
+                    axis_perm.append(_perm_symm(perm))
+        result = PointGroup(axis_perm, ndim=ndim)
+
     # reflections across axes and setting the origin
     # OBC axes are only symmetric w.r.t. their midpoint, (extent[i]-1)/2
     origin = []
-    for i in axes:
+    for i in range(ndim):
         result = result @ PointGroup([Identity(), _axis_reflection(i, ndim)], ndim=ndim)
         origin.append(0 if pbc[i] else (extent[i] - 1) / 2)
-    result = result.elems
-    result[0] = Identity()  # it would otherwise be an equivalent PGSymmetry
-    return PointGroup(result, ndim=ndim).change_origin(origin)
+
+    return result.change_origin(origin)
 
 
 def Grid(
@@ -65,6 +73,7 @@ def Grid(
     *,
     length: Sequence[int] = None,
     pbc: Union[bool, Sequence[bool]] = True,
+    color_edges: bool = False,
     **kwargs,
 ) -> Lattice:
     """
@@ -78,6 +87,9 @@ def Grid(
              This parameter can also be a list of booleans with same length as
              the parameter `length`, in which case each dimension will have
              PBC/OBC depending on the corresponding entry of `pbc`.
+        color_edges: generates nearest-neighbour edges colored according to direction
+                     i.e. edges along Cartesian direction #i have color i
+                     cannot be used with `max_neighbor_order` or `custom_edges`
         kwargs: Additional keyword arguments are passed on to the constructor of
             :ref:`netket.graph.Lattice`.
 
@@ -116,11 +128,13 @@ def Grid(
     ndim = len(extent)
     if isinstance(pbc, bool):
         pbc = [pbc] * ndim
+    if color_edges:
+        kwargs["custom_edges"] = [(0, 0, vec) for vec in np.eye(ndim)]
     return Lattice(
         basis_vectors=np.eye(ndim),
         extent=extent,
         pbc=pbc,
-        point_group=lambda: _grid_point_group(extent, pbc),
+        point_group=lambda: _grid_point_group(extent, pbc, color_edges),
         **kwargs,
     )
 
@@ -379,7 +393,7 @@ def Pyrochlore(
 def _hexagonal_general(
     extent, *, site_offsets=None, pbc: Union[bool, Sequence[bool]] = True, **kwargs
 ) -> Lattice:
-    basis = [[1, 0], [0.5, 0.75 ** 0.5]]
+    basis = [[1, 0], [0.5, 0.75**0.5]]
     # determine if full point group is realised by the simulation box
     point_group = planar.D(6) if np.all(pbc) and extent[0] == extent[1] else None
     return Lattice(
@@ -447,7 +461,7 @@ def Honeycomb(extent, *, pbc: Union[bool, Sequence[bool]] = True, **kwargs) -> L
     """
     return _hexagonal_general(
         extent,
-        site_offsets=[[0.5, 0.5 / 3 ** 0.5], [1, 1 / 3 ** 0.5]],
+        site_offsets=[[0.5, 0.5 / 3**0.5], [1, 1 / 3**0.5]],
         pbc=pbc,
         **kwargs,
     )
@@ -480,7 +494,54 @@ def Kagome(extent, *, pbc: Union[bool, Sequence[bool]] = True, **kwargs) -> Latt
     """
     return _hexagonal_general(
         extent,
-        site_offsets=[[0.5, 0], [0.25, 0.75 ** 0.5 / 2], [0.75, 0.75 ** 0.5 / 2]],
+        site_offsets=[[0.5, 0], [0.25, 0.75**0.5 / 2], [0.75, 0.75**0.5 / 2]],
         pbc=pbc,
         **kwargs,
     )
+
+
+def KitaevHoneycomb(
+    extent, *, pbc: Union[bool, Sequence[bool]] = True, **kwargs
+) -> Lattice:
+    r"""Constructs a honeycomb lattice of a given spatial extent.
+
+    Nearest-neighbour edges are coloured according to direction
+    (cf. Kitaev, https://doi.org/10.1016/j.aop.2005.10.005).
+    Periodic boundary conditions can also be imposed.
+    Sites are returned at the 2b Wyckoff positions.
+
+    Arguments:
+        extent: Number of unit cells along each direction, needs to be an array
+            of length 2
+        pbc: If `True`, the lattice will have periodic boundary conditions (PBC);
+             if `False`, the lattice will have open boundary conditions (OBC).
+             This parameter can also be a list of booleans with same length as
+             the parameter `length`, in which case each dimension will have
+             PBC/OBC depending on the corresponding entry of `pbc`.
+        kwargs: Additional keyword arguments are passed on to the constructor of
+            :ref:`netket.graph.Lattice`.
+
+
+    Example:
+        Construct a Kitaev honeycomb lattice with 3 × 3 unit cells:
+
+        >>> from netket.graph import Honeycomb
+        >>> g = KitaevHoneycomb(extent=[3, 3])
+        >>> print(g.n_nodes)
+        18
+        >>> print(len(g.edges(filter_color=2)))
+        9
+    """
+    return Lattice(
+        basis_vectors=[[1, 0], [0.5, 0.75**0.5]],
+        extent=extent,
+        site_offsets=[[0.5, 0.5 / 3**0.5], [1, 1 / 3**0.5]],
+        pbc=pbc,
+        point_group=planar.C(2) if np.all(pbc) else None,
+        custom_edges=[
+            (0, 1, [0.5, 0.5 / 3**0.5]),
+            (0, 1, [-0.5, 0.5 / 3**0.5]),
+            (0, 1, [0, -1 / 3**0.5]),
+        ],
+        **kwargs,
+    )
