@@ -14,15 +14,16 @@
 
 from .abstract_hilbert import AbstractHilbert
 from .discrete_hilbert import DiscreteHilbert
-from .abstract_continuous_space_particle import AbstractParticle
+from .homogeneous import HomogeneousHilbert
+
+from .continuous_hilbert import ContinuousHilbert
 
 from .custom_hilbert import CustomHilbert
 from .doubled_hilbert import DoubledHilbert
 from .spin import Spin
 from .fock import Fock
 from .qubit import Qubit
-from .continuous_space_boson import ContinuousBoson
-from .continuous_space_fermion import ContinuousFermion
+from .particle import Particle
 
 from .tensor_hilbert import TensorHilbert
 
