@@ -114,13 +114,24 @@ class TensorBoardLog:
         *args,
         **kwargs,
     ):
-        from tensorboardX import SummaryWriter
+        self._init_args = args
+        """Store the args for the lazily initialized SummaryWriter's constructor."""
+        self._init_kwargs = kwargs
+        """Store the kwargs for the lazily initialized SummaryWriter's constructor."""
 
-        self._writer = SummaryWriter(*args, **kwargs)
+        self._writer = None
+        """Lazily initialized summarywriter constructor"""
 
         self._old_step = 0
 
+    def _init_tensoboard(self):
+        from tensorboardX import SummaryWriter
+
+        self._writer = SummaryWriter(*self._init_args, **self._init_kwargs)
+
     def __call__(self, step, item, machine):
+        if self._writer is None:
+            self._init_tensoboard()
 
         data = []
         tree_log(item, "", data)
@@ -133,7 +144,8 @@ class TensorBoardLog:
         self._old_step = step
 
     def _flush_log(self):
-        self._writer.flush()
+        if self._writer is not None:
+            self._writer.flush()
 
     def _flush_params(self, _):
         return None
