@@ -59,8 +59,7 @@ from .symmetric_linear import (
 from .masked_linear import MaskedDense1D, MaskedConv1D, MaskedConv2D
 from .fast_masked_linear import FastMaskedDense1D, FastMaskedConv1D, FastMaskedConv2D
 
-from .module import Module
-from flax.linen.module import compact, enable_named_call, disable_named_call, Variable
+from flax.linen import Module, compact
 
 from .initializers import zeros, ones
 
