@@ -56,9 +56,20 @@ solvers = {}
 solvers_tol = {}
 
 solvers["gmres"] = partial(jax.scipy.sparse.linalg.gmres, tol=1e-6)
-solvers_tol[solvers["gmres"]] = 4e-4
+solvers_tol[solvers["gmres"], np.dtype("float64")] = 5e-4, 0
+solvers_tol[solvers["gmres"], np.dtype("float32")] = 1e-2, 1e-4
 solvers["cholesky"] = nk.optimizer.solver.cholesky
-solvers_tol[solvers["cholesky"]] = 1e-8
+solvers_tol[solvers["cholesky"], np.dtype("float64")] = 1e-8, 0
+solvers_tol[solvers["cholesky"], np.dtype("float32")] = 1e-2, 1e-4
+
+matmul_tol = {}
+matmul_tol[np.dtype("float64")] = 1e-7, 0
+matmul_tol[np.dtype("float32")] = 5e-4, 0
+
+
+dense_tol = {}
+dense_tol[np.dtype("float64")] = 1e-5, 1e-15
+dense_tol[np.dtype("float32")] = 5e-4, 1e-6
 
 
 RBM = partial(
@@ -73,13 +84,12 @@ RBMModPhase = partial(
 )
 
 models = {
-    "RBM[dtype=float]": partial(RBM, dtype=float),
-    "RBM[dtype=complex]": partial(RBM, dtype=complex),
-    "RBMModPhase[dtype=float]": partial(RBMModPhase, dtype=float),
+    "RBM[dtype=float64]": partial(RBM, dtype=np.dtype("float64")),
+    "RBM[dtype=float32]": partial(RBM, dtype=np.dtype("float32")),
+    "RBM[dtype=complex128]": partial(RBM, dtype=np.dtype("complex128")),
+    "RBMModPhase[dtype=float64]": partial(RBMModPhase, dtype=np.dtype("float64")),
 }
 
-dtypes = {"float": float, "complex": complex}
-
 
 @pytest.fixture(
     params=[pytest.param(modelT, id=name) for name, modelT in models.items()]
@@ -96,11 +106,17 @@ def vstate(request, model, chunk_size):
     N = 5
     hi = nk.hilbert.Spin(1 / 2, N)
 
+    k = jax.random.PRNGKey(3)
+    k1, k2 = jax.random.split(k)
+
     vstate = nk.vqs.MCState(
         nk.sampler.MetropolisLocal(hi),
         model,
+        seed=k1,
     )
-    vstate.init_parameters(normal(stddev=0.001), seed=jax.random.PRNGKey(3))
+
+    # initialize the same parameters on every rank
+    vstate.init_parameters(normal(stddev=0.001), seed=k2)
 
     vstate.sample()
 
@@ -122,8 +138,9 @@ def test_qgt_solve(qgt, vstate, solver, _mpi_size, _mpi_rank):
     S = qgt(vstate)
     x, _ = S.solve(solver, vstate.parameters)
 
-    jax.tree_multimap(
-        partial(testing.assert_allclose, rtol=solvers_tol[solver]),
+    rtol, atol = solvers_tol[solver, nk.jax.dtype_real(vstate.model.dtype)]
+    jax.tree_map(
+        partial(testing.assert_allclose, rtol=rtol, atol=atol),
         S @ x,
         vstate.parameters,
     )
@@ -142,8 +159,10 @@ def test_qgt_solve(qgt, vstate, solver, _mpi_size, _mpi_rank):
             S = qgt(vstate)
             x_all, _ = S.solve(solver, vstate.parameters)
 
-            jax.tree_multimap(
-                lambda a, b: np.testing.assert_allclose(a, b, rtol=0.00045), x, x_all
+            jax.tree_map(
+                lambda a, b: np.testing.assert_allclose(a, b, rtol=rtol, atol=atol),
+                x,
+                x_all,
             )
 
 
@@ -167,6 +186,9 @@ def test_qgt_solve_with_x0(qgt, vstate):
 )
 @pytest.mark.parametrize("chunk_size", [None, 16])
 def test_qgt_matmul(qgt, vstate, _mpi_size, _mpi_rank):
+
+    rtol, atol = matmul_tol[nk.jax.dtype_real(vstate.model.dtype)]
+
     S = qgt(vstate)
     rng = nkjax.PRNGSeq(0)
     y = jax.tree_map(
@@ -178,15 +200,17 @@ def test_qgt_matmul(qgt, vstate, _mpi_size, _mpi_rank):
     def check_same_dtype(x, y):
         assert x.dtype == y.dtype
 
-    jax.tree_multimap(check_same_dtype, x, y)
+    jax.tree_map(check_same_dtype, x, y)
 
     # test multiplication by dense gives same result...
     y_dense, unravel = nk.jax.tree_ravel(y)
     x_dense = S @ y_dense
     x_dense_unravelled = unravel(x_dense)
 
-    jax.tree_multimap(
-        lambda a, b: np.testing.assert_allclose(a, b), x, x_dense_unravelled
+    jax.tree_map(
+        lambda a, b: np.testing.assert_allclose(a, b, rtol=rtol, atol=atol),
+        x,
+        x_dense_unravelled,
     )
 
     if _mpi_size > 1:
@@ -203,7 +227,11 @@ def test_qgt_matmul(qgt, vstate, _mpi_size, _mpi_rank):
             S = qgt(vstate)
             x_all = S @ y
 
-            jax.tree_multimap(lambda a, b: np.testing.assert_allclose(a, b), x, x_all)
+            jax.tree_map(
+                lambda a, b: np.testing.assert_allclose(a, b, rtol=rtol, atol=atol),
+                x,
+                x_all,
+            )
 
 
 @pytest.mark.parametrize(
@@ -212,6 +240,9 @@ def test_qgt_matmul(qgt, vstate, _mpi_size, _mpi_rank):
 )
 @pytest.mark.parametrize("chunk_size", [None, 16])
 def test_qgt_dense(qgt, vstate, _mpi_size, _mpi_rank):
+
+    rtol, atol = dense_tol[nk.jax.dtype_real(vstate.model.dtype)]
+
     S = qgt(vstate)
 
     # test repr
@@ -244,7 +275,7 @@ def test_qgt_dense(qgt, vstate, _mpi_size, _mpi_rank):
             S = qgt(vstate)
             Sd_all = S.to_dense()
 
-            np.testing.assert_allclose(Sd_all, Sd, rtol=1e-5, atol=1e-15)
+            np.testing.assert_allclose(Sd_all, Sd, rtol=rtol, atol=atol)
 
 
 @pytest.mark.skipif_mpi
@@ -272,4 +303,4 @@ def test_qgt_pytree_diag_shift(qgt, vstate):
     )
     S = S.replace(diag_shift=diag_shift_tree)
     res = S @ v
-    jax.tree_multimap(lambda a, b: np.testing.assert_allclose(a, b), res, expected)
+    jax.tree_map(lambda a, b: np.testing.assert_allclose(a, b), res, expected)
